# `urn_citation`

A Python library for representing and manipulating CTS URNs (Canonical Text Services Uniform Resource Names) and CITE2 URNs.

See [reference documentation](reference.md) for full API details.

